@@ -1,7 +1,6 @@
 import hashlib
 
 import botocore
-import pytest
 from botocore import retryhandler, stub
 from botocore.args import ClientArgsCreator
 from botocore.awsrequest import AWSResponse
@@ -19,6 +18,7 @@ from botocore.credentials import (
     ContainerProvider,
     CredentialResolver,
     Credentials,
+    DeferredRefreshableCredentials,
     EnvProvider,
     InstanceMetadataProvider,
     OriginalEC2Provider,
@@ -43,7 +43,6 @@ from botocore.endpoint import (
 )
 from botocore.eventstream import EventStream
 from botocore.handlers import (
-    _looks_like_special_case_error,
     check_for_200_error,
     inject_presigned_url_ec2,
     inject_presigned_url_rds,
@@ -79,9 +78,13 @@ from botocore.session import Session, get_session
 from botocore.signers import (
     RequestSigner,
     S3PostPresigner,
+    _dsql_generate_db_auth_token,
+    add_dsql_generate_db_auth_token_methods,
     add_generate_db_auth_token,
     add_generate_presigned_post,
     add_generate_presigned_url,
+    dsql_generate_db_connect_admin_auth_token,
+    dsql_generate_db_connect_auth_token,
     generate_db_auth_token,
     generate_presigned_post,
     generate_presigned_url,
@@ -139,10 +142,10 @@ from dill.source import getsource
 _API_DIGESTS = {
     # args.py
     ClientArgsCreator.get_client_args: {
-        '2dc13a6f32c470bc415a2cfc1f82cf569b1a5196'
+        'd651b5c3d81738b7f2072b984eef8b5d4cfacd22',
     },
     ClientArgsCreator._build_endpoint_resolver: {
-        '0f80192233321ae4a55d95b68f5b8a68f3ad18e6',
+        '354033a66f90fc1d939a3309ae7d595d480020a6',
     },
     # client.py
     ClientCreator.create_client: {
@@ -202,15 +205,15 @@ _API_DIGESTS = {
     # config.py
     Config.merge: {'c3dd8c3ffe0da86953ceba4a35267dfb79c6a2c8'},
     Config: {
-        '823f8d031fc7218a600a56268a369aaa878f46c8',
+        'c7cf339ac7fb2d5fca9f133beb84d750bd4c9e30',
     },
     # credentials.py
     create_mfa_serial_refresher: {'9b5e98782fcacdcea5899a6d0d29d1b9de348bb0'},
     Credentials.get_frozen_credentials: {
-        'eb247f2884aee311bdabba3435e749c3b8589100'
+        '87ced1e435eda7738852e0569ddbff3b7a8e977f',
     },
     RefreshableCredentials.__init__: {
-        '25ee814f47e5ce617f57e893ae158e5fd6d358ea',
+        '88ab16aa041eb1cad8d666834613cbe5f0cf7514',
     },
     # We've overridden some properties
     RefreshableCredentials.__dict__['access_key'].fset: {
@@ -231,16 +234,27 @@ _API_DIGESTS = {
     RefreshableCredentials.__dict__['token'].fget: {
         '005c1b44b616f37739ce9276352e4e83644d8220'
     },
+    RefreshableCredentials.__dict__['account_id'].fset: {
+        '0d67de1c18dc80429b8537fe94a842175636f850',
+    },
+    RefreshableCredentials.__dict__['account_id'].fget: {
+        'd40a5f4571df3a239500a615ca0cc3fe77ac70ab',
+    },
     RefreshableCredentials._refresh: {
         'd5731d01db2812d498df19b4bd5d7c17519241fe'
     },
     RefreshableCredentials._protected_refresh: {
-        '9f8fdb76f41c3b1c64fd4d03d0701504626939e5'
+        '8b2d523a605a4f4728ad99861c14143838e56176',
     },
     RefreshableCredentials.get_frozen_credentials: {
         'f661c84a8b759786e011f0b1e8a468a0c6294e36'
     },
-    SSOCredentialFetcher: {'fa2a1dd73e0ec37e250c97f55a7b2c341a7f836a'},
+    DeferredRefreshableCredentials.__init__: {
+        'dd5ccda2b047854ae5e88907b654b57d35fe0dfd',
+    },
+    SSOCredentialFetcher._get_credentials: {
+        '13ac3b73e0745dfeaa934a8873179ca6c22a164f',
+    },
     SSOProvider.load: {'67aba81dd1def437f2035f5e20b0720b328d970a'},
     CachedCredentialFetcher._get_credentials: {
         '02a7d13599d972e3f258d2b53f87eeda4cc3e3a4'
@@ -249,10 +263,10 @@ _API_DIGESTS = {
         '0dd2986a4cbb38764ec747075306a33117e86c3d'
     },
     CachedCredentialFetcher._get_cached_credentials: {
-        'a9f8c348d226e62122972da9ccc025365b6803d6'
+        'f578b2527712d501c021f8236bd20e68e99201f5',
     },
     AssumeRoleCredentialFetcher._get_credentials: {
-        '5c575634bc0a713c10e5668f28fbfa8779d5a1da'
+        '51e265bebde5b193d79a680706f2c7efc7b56622',
     },
     AssumeRoleCredentialFetcher._create_client: {
         '27c76f07bd43e665899ca8d21b6ba2038b276fbb'
@@ -262,20 +276,22 @@ _API_DIGESTS = {
         'ab270375dfe425c5e21276590dea690fdbfe40a5'
     },
     AssumeRoleWithWebIdentityCredentialFetcher._get_credentials: {
-        '02eba9d4e846474910cb076710070348e395a819'
+        '23a7efbaf2022dcf713399649936cd9c2116f6c5',
     },
     AssumeRoleWithWebIdentityCredentialFetcher._assume_role_kwargs: {
         '8fb4fefe8664b7d82a67e0fd6d6812c1c8d92285'
     },
     # Ensure that the load method doesn't do anything we should asyncify
-    EnvProvider.load: {'39871a6ec3b3f5d51bc967122793e86b7ca6ed3c'},
+    EnvProvider.load: {
+        '9c6bb8f48ea4cb3dfbe7df925a269a077205d62b',
+    },
     ContainerProvider.__init__: {'ea6aafb2e12730066af930fb5a27f7659c1736a1'},
     ContainerProvider.load: {'57c35569050b45c1e9e33fcdb3b49da9e342fdcf'},
     ContainerProvider._retrieve_or_fail: {
-        'c99153a4c68927810a3edde09ee98c5ba33d3697'
+        '057ebdc912f15ec4903ab2e157f339d2ae740615',
     },
     ContainerProvider._create_fetcher: {
-        'a921ee40b9b4779f238adcf369a3757b19857fc7'
+        'f61e3e60fda55de7dbcf4a66865981f7cb0804b8',
     },
     InstanceMetadataProvider.load: {
         '15becfc0373ccfbc1bb200bd6a34731e61561d06'
@@ -295,14 +311,18 @@ _API_DIGESTS = {
     ProfileProviderBuilder._create_sso_provider: {
         'e463160179add7a1a513e46ee848447a216504aa'
     },
-    ConfigProvider.load: {'d0714da9f1f54cebc555df82f181c4913ce97258'},
+    ConfigProvider.load: {
+        'dab41451970911f4b578015a3083ff550c6b7beb',
+    },
     SharedCredentialProvider.load: {
-        '8a17d992e2a90ebc0e07ba5a5dfef2b725367496'
+        '833ec38b8361165e1bb285740e99c7ff7af161a5',
     },
     ProcessProvider.__init__: {'2e870ec0c6b0bc8483fa9b1159ef68bbd7a12c56'},
-    ProcessProvider.load: {'6866e1d3abbde7a14e83aea28cc49377faaca84b'},
+    ProcessProvider.load: {
+        '6691e82aeeccc4e07c30ee484ee31ebba5b6e2fb',
+    },
     ProcessProvider._retrieve_credentials_using: {
-        'c12acda42ddc5dfd73946adce8c155295f8c6b88'
+        'd8755c0bb80c4c9852c89276db6ec418f988f6f0',
     },
     CredentialResolver.load_credentials: {
         'ef31ba8817f84c1f61f36259da1cc6e597b8625a'
@@ -321,7 +341,7 @@ _API_DIGESTS = {
         '105c0c011e23d76a3b8bd3d9b91b6d945c8307a1'
     },
     AssumeRoleProvider._resolve_credentials_from_profile: {
-        'a87ece979f8c94c1afd5801156e2b39f0d6d45ab'
+        '3e4e6371dabe4deb3445495aeb702eed8a3fba63',
     },
     AssumeRoleProvider._resolve_static_credentials_from_profile: {
         'a470795f6ba451cf99ce7456fef24777f8087654'
@@ -446,13 +466,18 @@ _API_DIGESTS = {
     Session._register_response_parser_factory: {
         'bb8f7f3cc4d9ff9551f0875604747c4bb5030ff6'
     },
-    Session.create_client: {'a821ae3870f33b65b1ea7cd347ca0497ed306ccd'},
+    Session.create_client: {
+        '256ae18c8b119c66bfaf24ff224db8a8d2ad9661',
+    },
     Session._create_token_resolver: {
         '142df7a219db0dd9c96fd81dc9e84a764a2fe5fb'
     },
     Session._create_credential_resolver: {
         '87e98d201c72d06f7fbdb4ebee2dce1c09de0fb2'
     },
+    Session.set_credentials: {
+        '923e96e9386054d65b38a3871574dd32c0f5015f',
+    },
     Session.get_credentials: {'718da08b630569e631f93aedd65f1d9215bfc30b'},
     get_session: {'c47d588f5da9b8bde81ccc26eaef3aee19ddd901'},
     Session.get_service_data: {
@@ -488,14 +513,28 @@ _API_DIGESTS = {
         'd03631d6810e2453b8874bc76619927b694a4207',
     },
     S3PostPresigner.generate_presigned_post: {
-        '269efc9af054a2fd2728d5b0a27db82c48053d7f'
+        '269efc9af054a2fd2728d5b0a27db82c48053d7f',
+        '48418dc6c9b04fdc8689c7cb5b6eb987321a84e3',
     },
     add_generate_presigned_post: {'e30360f2bd893fabf47f5cdb04b0de420ccd414d'},
     generate_presigned_post: {
         'a3a834a08be2cf76c20ea137ba6b28e7a12f58ed',
+        'd93240c58dcda7b63cf2b7144ee0fea110f0e762',
     },
     add_generate_db_auth_token: {'f61014e6fac4b5c7ee7ac2d2bec15fb16fa9fbe5'},
     generate_db_auth_token: {'1f37e1e5982d8528841ce6b79f229b3e23a18959'},
+    add_dsql_generate_db_auth_token_methods: {
+        '95c68a1aac8ee549e11b5dc010b6bb03f9ea00ea',
+    },
+    _dsql_generate_db_auth_token: {
+        '53034b0475122209509db59fbd79a4ead70836cf',
+    },
+    dsql_generate_db_connect_auth_token: {
+        '29b5919b695113c55452f2325d0ff66dd719a647'
+    },
+    dsql_generate_db_connect_admin_auth_token: {
+        'd7e7a4899b8fd3a544dd1df95196517e2cfd5c84'
+    },
     # tokens.py
     create_token_resolver: {'b287f4879235a4292592a49b201d2b0bc2dbf401'},
     DeferredRefreshableToken.__init__: {
@@ -570,8 +609,7 @@ _API_DIGESTS = {
         'e7e5a8ce541110eb79bf98414171d3a1c137e32b'
     },
     S3RegionRedirectorv2.redirect_from_error: {
-        'ac37ca2ca48f7bde42d9659c01d5bd5bc08a78f9',
-        'bc01047b596b1d1113df7cc2481af9cca2a49267',
+        '8e3003ec881c7eab0945fe4b6e021ca488fbcd78',
     },
     S3RegionRedirectorv2.get_bucket_region: {
         'b5bbc8b010576668dc2812d657c4b48af79e8f99'
@@ -624,9 +662,8 @@ _API_DIGESTS = {
     inject_presigned_url_rds: {'b5d45b339686346e81b255d4e8c36e76d3fe6a78'},
     inject_presigned_url_ec2: {'48e09a5e4e95577e716be30f2d2706949261a07f'},
     parse_get_bucket_location: {'64ffbf5c6aa6ebd083f49371000fa046d0de1fc6'},
-    check_for_200_error: {'ded7f3aaef7b1a5d047c4dac86692ab55cbd7a13'},
-    _looks_like_special_case_error: {
-        '86946722d10a72b593483fca0abf30100c609178'
+    check_for_200_error: {
+        '3a00f0bea409528f8457d6569aecf05998094386',
     },
     # httpsession.py
     URLLib3Session: {
@@ -682,8 +719,7 @@ _API_DIGESTS = {
     AWSResponse.text: {'a724100ba9f6d51b333b8fe470fac46376d5044a'},
     # httpchecksum.py
     handle_checksum_body: {
-        '898cee7a7a5e5a02af7e0e65dcbb8122257b85df',
-        '6f15cc120818413e89aac088d130c729ba3d422c',
+        '040cb48d8ebfb5ca195d41deb55b38d1fcb489f8',
     },
     _handle_streaming_response: {
         '7ce971e012f9d4b04889f0af83f67281ed6a9e6e',
@@ -696,16 +732,18 @@ _API_DIGESTS = {
         '0761c4590c6addbe8c674e40fca9f7dd375a184b',
         '11dce986975df44f08ff61d7e86cba4f92f7c19f',
     },
+    AwsChunkedWrapper.read: {
+        '226db2259073a2b2e05f999e8ef55210394693d8',
+    },
     AwsChunkedWrapper._make_chunk: {
         '097361692f0fd6c863a17dd695739629982ef7e4'
     },
     AwsChunkedWrapper.__iter__: {'261e26d1061655555fe3dcb2689d963e43f80fb0'},
     apply_request_checksum: {
-        'bcc044f0655f30769994efab72b29e76d73f7e39',
-        '5ebac6a8f1475a6b42b356135bc5f5840ac07a55',
+        '6d904d118cd9d768935e38a60a73a46c67a8d440',
     },
     _apply_request_trailer_checksum: {
-        '28cdf19282be7cd2c99a734831ec4f489648bcc7'
+        '45f483dd8520bf67616a063bdf6386865aad3591',
     },
     # retryhandler.py
     retryhandler.create_retry_handler: {
@@ -749,15 +787,12 @@ _API_DIGESTS = {
 _PROTOCOL_PARSER_CONTENT = {'ec2', 'query', 'json', 'rest-json', 'rest-xml'}
 
 
-@pytest.mark.moto
 def test_protocol_parsers():
     # Check that no new parsers have been added
     current_parsers = set(PROTOCOL_PARSERS.keys())
     assert current_parsers == _PROTOCOL_PARSER_CONTENT
 
 
-# NOTE: this doesn't require moto but needs to be marked to run with coverage
-@pytest.mark.moto
 def test_patches():
     print(f"Botocore version: {botocore.__version__}")
 
